@@ -38,7 +38,7 @@ class GradCAMInterpreter(Interpreter):
 
         # init for usages during the interpretation.
         self._target_layer_name = None
-        self._feature_maps = None
+        self._feature_maps = {}
 
     def interpret(self,
                   inputs,
@@ -67,19 +67,21 @@ class GradCAMInterpreter(Interpreter):
         assert target_layer_name in [n for n, v in self.paddle_model.named_sublayers()], \
             f"target_layer_name {target_layer_name} does not exist in the given model, " \
             f"please check all valid layer names by [n for n, v in paddle_model.named_sublayers()]"
+        
+        if self._target_layer_name != target_layer_name:
+            self._target_layer_name = target_layer_name
+            self.paddle_prepared = False
 
-        self._target_layer_name = target_layer_name
         if not self.paddle_prepared:
             self._paddle_prepare()
 
+        feature_map, gradients, preds = self.predict_fn(data, label)
         if label is None:
-            _, _, preds = self.predict_fn(data, label)
             label = preds
-        label = np.array(label).reshape((bsz,))
 
-        feature_map, gradients, _ = self.predict_fn(data, label)
+        label = np.array(label).reshape((bsz,))
         f = np.array(feature_map.numpy())
-        g = np.array(gradients.numpy())
+        g = gradients
 
         # print(f.shape, g.shape)  # [bsz, channels, w, h]
 
@@ -107,10 +109,11 @@ class GradCAMInterpreter(Interpreter):
             self.paddle_model.train()
 
             def hook(layer, input, output):
-                self._feature_maps = output
+                self._feature_maps[layer._layer_name_for_hook] = output
 
             for n, v in self.paddle_model.named_sublayers():
                 if n == self._target_layer_name:
+                    v._layer_name_for_hook = n
                     v.register_forward_post_hook(hook)
                 if "batchnorm" in v.__class__.__name__.lower():
                     v._use_global_stats = True
@@ -129,9 +132,17 @@ class GradCAMInterpreter(Interpreter):
                 label_onehot = paddle.nn.functional.one_hot(
                     paddle.to_tensor(label), num_classes=out.shape[1])
                 target = paddle.sum(out * label_onehot, axis=1)
-                gradients = paddle.grad(
-                    outputs=[target], inputs=[self._feature_maps])[0]
-                return self._feature_maps, gradients, label
+
+                target.backward()
+                gradients = self._feature_maps[self._target_layer_name].grad
+                target.clear_gradient()
+
+                # gradients = paddle.grad(
+                #     outputs=[target], inputs=[self._feature_maps])[0]
+                if isinstance(gradients, paddle.Tensor):
+                    gradients = gradients.numpy()
+
+                return self._feature_maps[self._target_layer_name], gradients, label
 
         self.predict_fn = predict_fn
         self.paddle_prepared = True
