@@ -139,8 +139,10 @@ class IntGradCVInterpreter(Interpreter):
                 labels_onehot = paddle.nn.functional.one_hot(
                     paddle.to_tensor(labels), num_classes=out.shape[1])
                 target = paddle.sum(out * labels_onehot, axis=1)
-                gradients = paddle.grad(outputs=[target], inputs=[data])[0]
-                return gradients.numpy(), labels
+                target.backward()
+                gradients = data.grad
+
+                return gradients, labels
 
         self.predict_fn = predict_fn
         self.paddle_prepared = True
@@ -201,7 +203,8 @@ class IntGradNLPInterpreter(Interpreter):
 
         self._alpha = 1
         gradients, out, data_out = self.predict_fn(data, [0] * n)
-
+        out = paddle.nn.functional.softmax(paddle.to_tensor(out)).numpy()
+        
         if labels is None:
             labels = np.argmax(out, axis=1)
         else:
@@ -258,9 +261,11 @@ class IntGradNLPInterpreter(Interpreter):
                 labels_onehot = paddle.nn.functional.one_hot(
                     paddle.to_tensor(labels), num_classes=probs.shape[1])
                 target = paddle.sum(probs * labels_onehot, axis=1)
-                gradients = paddle.grad(
-                    outputs=[target], inputs=[self._embedding])[0]
-                return gradients.numpy(), probs.numpy(), self._embedding.numpy(
+                target.backward()
+                gradients = self._embedding.grad
+                if isinstance(gradients, paddle.Tensor):
+                    gradients = gradients.numpy()
+                return gradients, probs.numpy(), self._embedding.numpy(
                 )
 
         self.predict_fn = predict_fn
