@@ -1,17 +1,12 @@
-import typing
-from typing import Any, Callable, List, Tuple, Union
 
-import IPython.display as display
 import cv2
 import numpy as np
-import os, sys
-from PIL import Image
 import paddle
 from tqdm import tqdm
 
 from .abc_interpreter import Interpreter
 from ..data_processor.readers import preprocess_inputs, preprocess_save_path
-from ..data_processor.visualizer import visualize_heatmap
+from ..data_processor.visualizer import explanation_to_vis, show_vis_explanation, save_image
 
 
 class ScoreCAMInterpreter(Interpreter):
@@ -36,10 +31,13 @@ class ScoreCAMInterpreter(Interpreter):
         """
         Interpreter.__init__(self)
         self.paddle_model = paddle_model
-        self.use_cuda = use_cuda
         self.model_input_shape = model_input_shape
         self.paddle_prepared = False
 
+        self.use_cuda = use_cuda
+        if not paddle.is_compiled_with_cuda():
+            self.use_cuda = False
+
     def interpret(self,
                   inputs,
                   target_layer_name,
@@ -108,19 +106,19 @@ class ScoreCAMInterpreter(Interpreter):
                                     (interp.max() - interp.min())
                                     for interp in interpretations])
 
+        # visualization and save image.
         for i in range(b):
-            visualize_heatmap(interpretations[i], imgs[i], visual,
-                              save_path[i])
+            vis_explanation = explanation_to_vis(imgs[i], interpretations[i], style='overlay_heatmap')
+            if visual:
+                show_vis_explanation(vis_explanation)
+            if save_path[i] is not None:
+                save_image(save_path[i], vis_explanation)
 
         return interpretations
 
     def _paddle_prepare(self, predict_fn=None):
         if predict_fn is None:
-            if self.use_cuda:
-                paddle.set_device('gpu:0')
-            else:
-                paddle.set_device('cpu')
-
+            paddle.set_device('gpu:0' if self.use_cuda else 'cpu')
             self.paddle_model.eval()
 
             self._feature_maps = None
@@ -141,7 +139,6 @@ class ScoreCAMInterpreter(Interpreter):
             def predict_fn(data):
                 global feature_maps
                 data = paddle.to_tensor(data)
-                data.stop_gradient = False
                 out = self.paddle_model(data)
                 probs = paddle.nn.functional.softmax(out, axis=1)
                 return self._feature_maps.numpy(), probs.numpy()
